==> hlw-core-0.0.2-20250707.064344-89-sources.jar: cn/gtmap/hlw/core/dto/sqxx/tdxx/TdxxQueryResultDTO.java <==
package cn.gtmap.hlw.core.dto.sqxx.tdxx;

import cn.gtmap.hlw.core.annotation.ZdDzConfig;
import cn.gtmap.hlw.core.constant.dict.ZdDzConstant;
import lombok.Data;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2024/3/7
 * @description
 */
@Data
public class TdxxQueryResultDTO {
    /**
     * 地籍号
     */
    private String zdh;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 土地使用权人
     */
    private String tdsyqr;
    /**
     * 宗地面积
     */
    private Double zdmj;
    /**
     * 土地使用起始时间
     */
    private String tdsyqssj;
    /**
     * 土地使用结束时间
     */
    private String tdsyjssj;
    /**
     * 土地使用起始时间2
     */
    private String tdsyqssj2;
    /**
     * 土地使用结束时间2
     */
    private String tdsyjssj2;
    /**
     * 土地使用起始时间3
     */
    private String tdsyqssj3;
    /**
     * 土地使用结束时间3
     */
    private String tdsyjssj3;
    /**
     * 土地使用权类型
     */
    @ZdDzConfig(field = "tdsyqlx", tableName = ZdDzConstant.ZD_DZ_SYQLX, dmToDm = true)
    private String tdsyqlx;
    /**
     * 土地使用权类型
     */
    @ZdDzConfig(field = "tdsyqlx", tableName = ZdDzConstant.ZD_DZ_SYQLX, dmToMc = true)
    private String tdsyqlxmc;
    /**
     * 土地用途
     */
    @ZdDzConfig(field = "tdyt", tableName = ZdDzConstant.ZD_DZ_TDYT, dmToDm = true)
    private String tdyt;
    /**
     * 土地用途2
     */
    @ZdDzConfig(field = "tdyt", tableName = ZdDzConstant.ZD_DZ_TDYT, dmToDm = true)
    private String tdyt2;
    /**
     * 土地用途3
     */
    @ZdDzConfig(field = "tdyt", tableName = ZdDzConstant.ZD_DZ_TDYT, dmToDm = true)
    private String tdyt3;
    /**
     * 坐落
     */
    private String tdzl;
    /**
     * 分摊土地面积
     */
    private Double fttdmj;
    /**
     * 独用土地面积
     */
    private Double dytdmj;
    /**
     * 土地使用权面价
     */
    private Double tdsyqmj;
    /**
     * 权利性质代码
     */
    @ZdDzConfig(field = "zdzhqlxz", tableName = ZdDzConstant.ZD_DZ_QLXZ, dmToDm = true)
    private String zdzhqlxz;
    /**
     * 权利性质名称
     */
    @ZdDzConfig(field = "zdzhqlxz", tableName = ZdDzConstant.ZD_DZ_QLXZ, dmToMc = true)
    private String zdzhqlxzmc;
    /**
     * 权利设定方式代码
     */
    private String qlsdfs;
    /**
     * 权利设定方式名称
     */
    private String qlsdfsmc;
    /**
     * 性质区代码
     */
    private String qydm;
    /**
     * 取得价格
     */
    private String qdjg;
    /**
     * 附记
     */
    private String fj;
}

==> hlw-core-0.0.2-20251204.081819-172-sources.jar: cn/gtmap/hlw/core/dto/sqxx/tdxx/TdxxQueryResultDTO.java <==
package cn.gtmap.hlw.core.dto.sqxx.tdxx;

import cn.gtmap.hlw.core.annotation.ZdDzConfig;
import cn.gtmap.hlw.core.constant.dict.ZdDzConstant;
import lombok.Data;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2024/3/7
 * @description
 */
@Data
public class TdxxQueryResultDTO {
    /**
     * 地籍号
     */
    private String zdh;
    /**
     * 不动产单元号
     */
    private String bdcdyh;
    /**
     * 土地使用权人
     */
    private String tdsyqr;
    /**
     * 宗地面积
     */
    private Double zdmj;
    /**
     * 土地使用起始时间
     */
    private String tdsyqssj;
    /**
     * 土地使用结束时间
     */
    private String tdsyjssj;
    /**
     * 土地使用起始时间2
     */
    private String tdsyqssj2;
    /**
     * 土地使用结束时间2
     */
    private String tdsyjssj2;
    /**
     * 土地使用起始时间3
     */
    private String tdsyqssj3;
    /**
     * 土地使用结束时间3
     */
    private String tdsyjssj3;
    /**
     * 土地使用权类型
     */
    @ZdDzConfig(field = "tdsyqlx", tableName = ZdDzConstant.ZD_DZ_SYQLX, dmToDm = true)
    private String tdsyqlx;
    /**
     * 土地使用权类型
     */
    @ZdDzConfig(field = "tdsyqlx", tableName = ZdDzConstant.ZD_DZ_SYQLX, dmToMc = true)
    private String tdsyqlxmc;
    /**
     * 土地用途
     */
    @ZdDzConfig(field = "tdyt", tableName = ZdDzConstant.ZD_DZ_TDYT, dmToDm = true)
    private String tdyt;
    /**
     * 土地用途名称
     */
    private String tdytmc;
    /**
     * 土地用途2
     */
    @ZdDzConfig(field = "tdyt", tableName = ZdDzConstant.ZD_DZ_TDYT, dmToDm = true)
    private String tdyt2;
    /**
     * 土地用途3
     */
    @ZdDzConfig(field = "tdyt", tableName = ZdDzConstant.ZD_DZ_TDYT, dmToDm = true)
    private String tdyt3;
    /**
     * 坐落
     */
    private String tdzl;
    /**
     * 分摊土地面积
     */
    private Double fttdmj;
    /**
     * 独用土地面积
     */
    private Double dytdmj;
    /**
     * 土地使用权面价
     */
    private Double tdsyqmj;
    /**
     * 权利性质代码
     */
    @ZdDzConfig(field = "zdzhqlxz", tableName = ZdDzConstant.ZD_DZ_QLXZ, dmToDm = true)
    private String zdzhqlxz;
    /**
     * 权利性质名称
     */
    @ZdDzConfig(field = "zdzhqlxz", tableName = ZdDzConstant.ZD_DZ_QLXZ, dmToMc = true)
    private String zdzhqlxzmc;

    /**
     * 权利类型代码
     */
    private String zdzhqllx;
    /**
     * 权利类型名称
     */
    private String zdzhqllxmc;
    /**
     * 权利设定方式代码
     */
    private String qlsdfs;
    /**
     * 权利设定方式名称
     */
    private String qlsdfsmc;
    /**
     * 性质区代码
     */
    private String qydm;
    /**
     * 取得价格
     */
    private String qdjg;
    /**
     * 附记
     */
    private String fj;
    /**
     * 抵押状态
     */
    private String dyzt;

    /**
     * 预抵押状态
     */
    private String ydyzt;

    /**
     * 在建工程抵押状态
     */
    private String zjgcdyzt;

    /**
     * 查封状态
     */
    private String cfzt;

    /**
     * 预查封状态
     */
    private String ycfzt;

    /**
     * 登记状态
     */
    private String djzt;
}
